@@ -43,7 +43,7 @@ def __check_alias__(
 	overwrite = "--overwrite" in sys.argv
 	if (("--force" in sys.argv or "--forced" in sys.argv or overwrite) and present) or (present or not os.path.exists(str(path))):
 		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
-		sudo = Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
+		sudo = Boolean("--sudo" in sys.argv).string(true="sudo ",false="")
 		os.system(f"{sudo}touch {path}")
 		os.system(f"{sudo}chmod +x {path}")
 		os.system(f"{sudo}chown {USER}:{GROUP} {path}")
